summaryrefslogtreecommitdiffstats
path: root/kstars/kstars
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 08:15:31 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 08:15:31 -0600
commit088cc453ec425bf86d610880d09645ea166a14fa (patch)
tree6e7daebcbfb5e5a1a079c26254156995c849b3e7 /kstars/kstars
parenteb973d5c889d9c1e859ecdd682e9c05d22599920 (diff)
downloadtdeedu-088cc453ec425bf86d610880d09645ea166a14fa.tar.gz
tdeedu-088cc453ec425bf86d610880d09645ea166a14fa.zip
Rename KLocale to enhance compatibility with KDE4
Diffstat (limited to 'kstars/kstars')
-rw-r--r--kstars/kstars/detaildialog.cpp2
-rw-r--r--kstars/kstars/infoboxes.cpp2
-rw-r--r--kstars/kstars/kstarsdata.cpp2
-rw-r--r--kstars/kstars/kstarsdata.h6
-rw-r--r--kstars/kstars/tools/altvstime.h2
5 files changed, 7 insertions, 7 deletions
diff --git a/kstars/kstars/detaildialog.cpp b/kstars/kstars/detaildialog.cpp
index b4fd1b75..e8817ab7 100644
--- a/kstars/kstars/detaildialog.cpp
+++ b/kstars/kstars/detaildialog.cpp
@@ -309,7 +309,7 @@ void DetailDialog::createPositionTab( const KStarsDateTime &ut, GeoLocation *geo
vlay->addWidget( Pos );
//Coordinates Section:
- //Don't use KLocale::formatNumber() for the epoch string,
+ //Don't use TDELocale::formatNumber() for the epoch string,
//because we don't want a thousands-place separator!
TQString sEpoch = TQString::number( ut.epoch(), 'f', 1 );
//Replace the decimal point with localized decimal symbol
diff --git a/kstars/kstars/infoboxes.cpp b/kstars/kstars/infoboxes.cpp
index 922380da..34ba2175 100644
--- a/kstars/kstars/infoboxes.cpp
+++ b/kstars/kstars/infoboxes.cpp
@@ -348,7 +348,7 @@ bool InfoBoxes::timeChanged( const KStarsDateTime &ut, const KStarsDateTime &lt,
TQString STString;
STString = STString.sprintf( "%02d:%02d:%02d ", lst->hour(), lst->minute(), lst->second() );
- //Don't use KLocale::formatNumber() for Julian Day because we don't want
+ //Don't use TDELocale::formatNumber() for Julian Day because we don't want
//thousands-place separators
TQString JDString = TQString::number( ut.djd(), 'f', 2 );
JDString.replace( ".", TDEGlobal::locale()->decimalSymbol() );
diff --git a/kstars/kstars/kstarsdata.cpp b/kstars/kstars/kstarsdata.cpp
index 93a2c0f4..73e85d6c 100644
--- a/kstars/kstars/kstarsdata.cpp
+++ b/kstars/kstars/kstarsdata.cpp
@@ -71,7 +71,7 @@ KStarsData::KStarsData() : stdDirs(0), locale(0),
//standard directories and locale objects
stdDirs = new TDEStandardDirs();
- locale = new KLocale( "kstars" );
+ locale = new TDELocale( "kstars" );
//Check to see if config file already exists. If not, set
//useDefaultOptions = true
diff --git a/kstars/kstars/tools/altvstime.h b/kstars/kstars/tools/altvstime.h
index 654c3f3c..f68d1612 100644
--- a/kstars/kstars/tools/altvstime.h
+++ b/kstars/kstars/tools/altvstime.h
@@ -25,7 +25,7 @@ class TQTime;
class TQVariant;
class TQVBoxLayout;
class KDialogBase;
-class KLocale;
+class TDELocale;
class SkyObject;
class SkyPoint;
class dms;
diff --git a/kstars/kstars/kstarsdata.h b/kstars/kstars/kstarsdata.h
index 22f9b273..652113bf 100644
--- a/kstars/kstars/kstarsdata.h
+++ b/kstars/kstars/kstarsdata.h
@@ -441,9 +441,9 @@ public:
*/
bool isTimeRunningForward() { return TimeRunsForward; }
/**@return pointer to the localization (KLocale) object
*/
- KLocale *getLocale() { return locale; }
+ TDELocale *getLocale() { return locale; }
/**@return pointer to the Earth object
*/
@@ -736,7 +736,7 @@ private:
TQString cnameFile;
TDEStandardDirs *stdDirs;
- KLocale *locale;
+ TDELocale *locale;
dms *LST, *HourAngle;
@@ -441,9 +441,9 @@ public:
*/
bool isTimeRunningForward() { return TimeRunsForward; }
- /**@return pointer to the localization (KLocale) object
+ /**@return pointer to the localization (TDELocale) object
*/